"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const classnames_1 = __importDefault(require("classnames"));
const react_1 = __importStar(require("react"));
const color_1 = __importDefault(require("./helpers/color"));
const Alpha_1 = __importDefault(require("./Alpha"));
const Board_1 = __importDefault(require("./Board"));
const Params_1 = __importDefault(require("./Params"));
const Preview_1 = __importDefault(require("./Preview"));
const Ribbon_1 = __importDefault(require("./Ribbon"));
const prefixCls_1 = __importDefault(require("./prefixCls"));
const tinycolor2_1 = __importDefault(require("tinycolor2"));
const use_optional_state_1 = __importDefault(require("use-optional-state"));
const Panel = props => {
    const { value: propsValue, defaultValue, className, onChange, enableAlpha } = props;
    const prefixCls = props.prefixCls;
    const [value, setValue] = use_optional_state_1.default({
        initialValue: defaultValue,
        controlledValue: propsValue,
        onChange
    });
    const ref = react_1.useRef(null);
    const [focusingOnInput, setFocusingOnInput] = react_1.useState(false);
    react_1.useEffect(() => {
        if (value.open) {
            setTimeout(() => {
                var _a;
                (_a = ref.current) === null || _a === void 0 ? void 0 : _a.focus();
            }, 1);
        }
    }, []);
    // Some weird react set state stuff causes an error when clicking at rainbow rect
    // after focusing on input
    // So we need to delay it
    const blurTimer = react_1.useRef();
    const handleBlur = () => {
        // Clear original blur timer
        clearTimeout(blurTimer.current);
        if (focusingOnInput) {
            blurTimer.current = setTimeout(() => {
                setFocusingOnInput(false);
            }, 100 /* 100 I don't know why but og code had 100 */);
        }
        else {
            setValue(Object.assign(Object.assign({}, value), { open: false }));
        }
    };
    const handleFocus = () => {
        // Don't focus while blurring
        if (blurTimer.current !== undefined) {
            clearTimeout(blurTimer.current);
        }
        else {
            setFocusingOnInput(true);
        }
    };
    const handleChange = color => {
        setValue(Object.assign(Object.assign({}, value), { color: new tinycolor2_1.default(color.hex).setAlpha(value.color.getAlpha()) }));
    };
    const handleAlphaChange = alpha => {
        setValue(Object.assign(Object.assign({}, value), { color: new tinycolor2_1.default(value.color).setAlpha(alpha / 100) }));
    };
    const color = new color_1.default(value.color);
    const alpha = value.color.getAlpha();
    return (react_1.default.createElement("div", { ref: ref, className: classnames_1.default(prefixCls, className), onBlur: handleBlur, onFocus: handleFocus, tabIndex: 0 },
        react_1.default.createElement("div", { className: `${prefixCls}-inner` },
            react_1.default.createElement(Board_1.default, { rootPrefixCls: prefixCls, color: color, onChange: handleChange }),
            react_1.default.createElement("div", { className: classnames_1.default(`${prefixCls}-wrap`, enableAlpha && `${prefixCls}-wrap-has-alpha`) },
                react_1.default.createElement("div", { className: `${prefixCls}-wrap-ribbon` },
                    react_1.default.createElement(Ribbon_1.default, { rootPrefixCls: prefixCls, color: color, onChange: handleChange })),
                enableAlpha &&
                    react_1.default.createElement("div", { className: `${prefixCls}-wrap-alpha` },
                        react_1.default.createElement(Alpha_1.default, { rootPrefixCls: prefixCls, alpha: alpha * 100, color: color, onChange: handleAlphaChange })),
                react_1.default.createElement("div", { className: `${prefixCls}-wrap-preview` },
                    react_1.default.createElement(Preview_1.default, { rootPrefixCls: prefixCls, alpha: alpha * 100, color: color, onChange: handleChange }))),
            react_1.default.createElement("div", { className: `${prefixCls}-wrap`, style: { height: 40, marginTop: 6 } },
                react_1.default.createElement(Params_1.default, { prefixCls: `${prefixCls}-params`, value: value, onChange: setValue, enableAlpha: enableAlpha })))));
};
Panel.defaultProps = {
    prefixCls: `${prefixCls_1.default}-panel`
};
exports.default = Panel;
