"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const classnames_1 = __importDefault(require("classnames"));
const react_1 = __importDefault(require("react"));
const tinycolor2_1 = __importDefault(require("tinycolor2"));
const getChannelValue_1 = __importDefault(require("./helpers/getChannelValue"));
const ChangeOnBlur_1 = __importDefault(require("./ChangeOnBlur"));
const setChannelValue_1 = __importDefault(require("./helpers/setChannelValue"));
const modes_1 = __importDefault(require("./helpers/modes"));
const useLoop_1 = __importDefault(require("./helpers/useLoop"));
const round_1 = __importDefault(require("round"));
const rgbChannelInputProps = {
    min: 0,
    max: 255
};
const ratioInputProps = {
    min: 0,
    max: 1,
    step: 0.01
};
const modeInputProps = {
    RGB: [rgbChannelInputProps, rgbChannelInputProps, rgbChannelInputProps],
    HSL: [{
            min: 0,
            max: 360
        }, ratioInputProps, ratioInputProps]
};
const Params = props => {
    const { prefixCls, value, onChange, enableAlpha } = props;
    const [mode, nextMode] = useLoop_1.default(modes_1.default);
    const handleChange = hex => {
        const color = new tinycolor2_1.default(hex);
        console.log(hex, color.isValid());
        if (color.isValid()) {
            onChange(value => (Object.assign(Object.assign({}, value), { color: color })));
        }
    };
    const handleChangeAlpha = ({ target: { valueAsNumber: newAlpha } }) => {
        onChange(value => (Object.assign(Object.assign({}, value), { color: new tinycolor2_1.default(value.color).setAlpha(newAlpha) })));
    };
    const channels = getChannelValue_1.default(value.color, mode);
    const alpha = value.color.getAlpha();
    return (react_1.default.createElement("div", { className: classnames_1.default(prefixCls, enableAlpha && `${prefixCls}-has-alpha`) },
        react_1.default.createElement("div", { className: `${prefixCls}-input` },
            react_1.default.createElement(ChangeOnBlur_1.default, { className: `${prefixCls}-hex`, maxLength: 6, value: value.color.toHex(), onChange: handleChange }),
            channels.map((channel, index) => {
                const handleChange = e => {
                    const newColor = setChannelValue_1.default(value.color, mode, index, e.target.valueAsNumber);
                    if (newColor.isValid())
                        onChange(value => (Object.assign(Object.assign({}, value), { color: newColor })));
                };
                return (react_1.default.createElement("input", Object.assign({}, modeInputProps[mode][index], { key: mode[index], type: 'number', value: round_1.default(channel, modeInputProps[mode][index].step), onChange: handleChange })));
            }),
            enableAlpha &&
                react_1.default.createElement("input", { key: 'alpha', type: 'number', value: alpha, step: 0.01, onChange: handleChangeAlpha })),
        react_1.default.createElement("div", { className: `${prefixCls}-label` },
            react_1.default.createElement("label", { className: `${prefixCls}-label-hex` }, "Hex"),
            channels.map((channel, index) => (react_1.default.createElement("label", { key: mode[index], className: `${prefixCls}-label-number`, onClick: nextMode }, mode[index]))),
            enableAlpha && react_1.default.createElement("label", { className: `${prefixCls}-label-alpha` }, "A"))));
};
exports.default = Params;
